.. image:: .github/banner.png
  :class: with-border
  :width: 1280

========
Overview :flags:
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs:
      - |docs|
    * - tests:
      - | |travis| |requires| |codecov|
    * - package:
      - | |version|
    * - infra:
      - | |github-actions|

.. |docs| image:: https://readthedocs.org/projects/sylenium/badge/?style=flat
    :target: https://sylenium.readthedocs.io/en/latest/
    :alt: Documentation Status

.. |travis| image:: https://api.travis-ci.org/symonk/sylenium.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/symonk/sylenium

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/symonk/sylenium?branch=master&svg=true
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/symonk/sylenium

.. |requires| image:: https://requires.io/github/symonk/sylenium/requirements.svg?branch=master
    :alt: Requirements Status
    :target: https://requires.io/github/symonk/sylenium/requirements/?branch=master

.. |codecov| image:: https://codecov.io/gh/symonk/sylenium/branch/master/graphs/badge.svg?branch=master
    :alt: Coverage Status
    :target: https://codecov.io/github/symonk/sylenium

.. |version| image:: https://img.shields.io/pypi/v/sylenium.svg
    :alt: PyPI Package latest release
    :target: https://pypi.org/project/sylenium

.. |wheel| image:: https://img.shields.io/pypi/wheel/sylenium.svg
    :alt: PyPI Wheel
    :target: https://pypi.org/project/sylenium

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/sylenium.svg
    :alt: Supported versions
    :target: https://pypi.org/project/sylenium

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/sylenium.svg
    :alt: Supported implementations
    :target: https://pypi.org/project/sylenium

.. |github-actions| image:: https://github.com/symonk/sylenium/workflows/Release%20Sylenium/badge.svg
    :alt: Automated Releasing
    :target: https://github.com/symonk/sylenium/workflows/Release%20Sylenium/badge.svg


.. end-badges

========
What is Sylenium? :flags:
========

The goal of sylenium is to create a test framework agnostic browser (selenium wrapper) automation library to help
development teams write end to end tests for their web applications without all the necessary boilerplate that is
required to achieve stability with selenium.


=============
Official Documentation :flags:
=============

https://sylenium.readthedocs.io/

==============
Configuring Sylenium :flags:
==============

.. code-block:: python

    # Coming soon

==============
Quick Start :flags:
==============

.. code-block:: python

    # Coming soon

==============
Sylenium-pytest :flags:
==============

Plugin (coming soon)
